@@ -2,6 +2,10 @@ package X11::Xlib::XVisualInfo;
 require X11::Xlib::Struct;
 __END__
 
+=head1 NAME
+
+X11::Xlib::XVisualInfo - Struct to list details of a Visual*
+
 =head1 SYNOPSIS
 
   my $conn= X11::Xlib->new();
@@ -36,4 +40,20 @@ making lots of method calls.
 
 See parent class L<X11::Xlib::Struct>
 
+=head1 AUTHOR
+
+Olivier Thauvin, E<lt>nanardon@nanardon.zarb.orgE<gt>
+
+Michael Conrad, E<lt>mike@nrdvana.netE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2009-2010 by Olivier Thauvin
+
+Copyright (C) 2017 by Michael Conrad
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
